==> segatex-7.880.tar.gz: segatex-7.880/admin/sqlrefpolicy_prepare3.sh <==
#
# segatex SELinux tool.
#
# Copyright (C) 2007-2010 Shintaro Fujiwara 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#!/bin/sh
######this script basically echoes every lines in current directory recursively.
######this script echoes interface name and target domains.
INPUTFILE="interface_allow.txt"
OUTPUTFILE_PRE="target_domain_pre.txt"
OUTPUTFILE_PRE_NEXT="target_domain_pre_next.txt"
OUTPUTFILE_PRE_NEXT_2="target_domain_pre_next_2.txt"
OUTPUTFILE_PRE_NEXT_3="target_domain_pre_next_3.txt"
OUTPUTFILE_PRE_NEXT_4="target_domain_pre_next_4.txt"
OUTPUTFILE_PRE_NEXT_5="target_domain_pre_next_5.txt"
OUTPUTFILE_PRE_NEXT_6="target_domain_pre_next_6.txt"
OUTPUTFILE="target_domain.txt"
INTERFACE_NAME=""
BRACE_LEFT="{"
BRACE_RIGHT="}"
BLANK=" "
TEMP_STR=
TEMP_STR2=
TEMP_STR3=
TEMP_STR4=
TEMP_STR5=
TEMP_STR6=
TEMP_STR6_1=
TEMP_STR7=
TEMP_STR7_2=
TEMP_STR7_3=
TEMP_STR7_4=
TEMP_STR7_5=
TEMP_STR7_6=
TEMP_STR8=
TEMP_STR9=

ECHO_LINES(){
	while read LINE
	do
		echo $LINE | grep "'$"
		#################for target domain################
		TEMP_STR=`echo $LINE | grep "allow" | awk '{ print $3 }'| awk -F":" '{ print $1 }'`
		TEMP_STR2=`echo $LINE | grep "allow" | awk '{ print $4 }'| awk -F":" '{ print $1 }'`
		#################for object class################
		TEMP_STR5=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk '{ print $1 }'`
		##########for permissions in { a b c }################
		TEMP_STR7=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk '{ print $2 }'`
		TEMP_STR7_2=`echo $TEMP_STR7 |grep "{"`
		TEMP_STR7_3=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk -F"{" '{ print $2 }'`
		TEMP_STR7_4=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk -F"{" '{ print $3 }'`
		TEMP_STR7_5=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk -F"{" '{ print $4 }'`
		TEMP_STR7_6="$TEMP_STR7_3""$TEMP_STR7_4""$TEMP_STR7_5"
		########### matches target domain { a_t b_t } and { a_t b_t } c_t } ##################### 
		if [ "$TEMP_STR" = "$BRACE_LEFT" ]; then
			TEMP_STR6=`echo $LINE | awk -F":" '{ print $1 }' | awk -F"{" '{ print $2 }' | awk -F"}" '{ print $1 }'`
			TEMP_STR6_1=`echo $LINE | awk -F":" '{ print $1 }' | awk -F"{" '{ print $2 }' | awk -F"}" '{ print $2 }'`
			#echo "$TEMP_STR6""$TEMP_STR6_1""&""$TEMP_STR5""&"">>>>>""$TEMP_STR7""$TEMP_STR7_6"
			echo "$TEMP_STR6""$TEMP_STR6_1""&""$TEMP_STR5""&""$TEMP_STR7""$TEMP_STR7_6"
		else
			#echo "$TEMP_STR""&""$TEMP_STR5""&""<<<<<""$TEMP_STR7""$TEMP_STR7_6"
			echo "$TEMP_STR""&""$TEMP_STR5""&""$TEMP_STR7""$TEMP_STR7_6"
		fi
		########### matches permissions { { a b c } } or { { a b c } d }##################### 
		if [ "$TEMP_STR" != "$BRACE_LEFT" ]; then
			if [ "$TEMP_STR7_2" != "" ]; then
				#echo "$TEMP_STR""&""$TEMP_STR5""&""|||||""$TEMP_STR7_6"
				echo "$TEMP_STR""&""$TEMP_STR5""&""$TEMP_STR7_6"
				if [ "$TEMP_STR7" = "$BRACE_LEFT" ]; then
					TEMP_STR8=`echo $LINE | awk -F":" '{ print $2 }' | awk '{ print $2 }'`
					TEMP_STR9=`echo $LINE | awk -F":" '{ print $2 }' | awk '{ print $3 }'`
					#echo "$TEMP_STR3""$TEMP_STR4""&""$TEMP_STR5""&""((((""$TEMP_STR8""$TEMP_STR9"
					echo "$TEMP_STR3""$TEMP_STR4""&""$TEMP_STR5""&""$TEMP_STR8""$TEMP_STR9"
				else
					#echo "$TEMP_STR""&""$TEMP_STR5""&""xxxxx""$TEMP_STR7_6"
					echo "$TEMP_STR""&""$TEMP_STR5""&""$TEMP_STR7_6"
				fi
			fi
		fi

	done < $INPUTFILE >> $OUTPUTFILE_PRE
}
rm $OUTPUTFILE_PRE
rm $OUTPUTFILE_PRE_NEXT
rm $OUTPUTFILE_PRE_NEXT_2
rm $OUTPUTFILE_PRE_NEXT_3
rm $OUTPUTFILE_PRE_NEXT_4
rm $OUTPUTFILE_PRE_NEXT_5
rm $OUTPUTFILE_PRE_NEXT_6
rm $OUTPUTFILE
ECHO_LINES
sed 's/$(.*)?_t//g' $OUTPUTFILE_PRE > $OUTPUTFILE_PRE_NEXT
sed 's/$[12]//g' $OUTPUTFILE_PRE_NEXT > $OUTPUTFILE_PRE_NEXT_2
sed 's/[{};]//g' $OUTPUTFILE_PRE_NEXT_2 > $OUTPUTFILE_PRE_NEXT_3
sed 's/  / /g' $OUTPUTFILE_PRE_NEXT_3 > $OUTPUTFILE_PRE_NEXT_4
sed '/^[$&]/d' $OUTPUTFILE_PRE_NEXT_4 > $OUTPUTFILE_PRE_NEXT_5
sed '/^[$&]/d' $OUTPUTFILE_PRE_NEXT_5 > $OUTPUTFILE_PRE_NEXT_6
uniq $OUTPUTFILE_PRE_NEXT_6 > $OUTPUTFILE
rm $OUTPUTFILE_PRE
rm $OUTPUTFILE_PRE_NEXT
rm $OUTPUTFILE_PRE_NEXT_2
rm $OUTPUTFILE_PRE_NEXT_3
rm $OUTPUTFILE_PRE_NEXT_4
rm $OUTPUTFILE_PRE_NEXT_5
rm $OUTPUTFILE_PRE_NEXT_6

exit 0

==> segatex-7.980.tar.gz: segatex-7.980/admin/sqlrefpolicy_prepare3.sh <==
#
# segatex SELinux tool.
#
# Copyright (C) 2007-2013 Shintaro Fujiwara 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

#!/bin/sh
######this script echoes interface name and target domains.
INPUTFILE="interface_allow.txt"
OUTPUTFILE_PRE="target_domain_pre.txt"
OUTPUTFILE_PRE_NEXT="target_domain_pre_next.txt"
OUTPUTFILE_PRE_NEXT_2="target_domain_pre_next_2.txt"
OUTPUTFILE_PRE_NEXT_3="target_domain_pre_next_3.txt"
OUTPUTFILE_PRE_NEXT_4="target_domain_pre_next_4.txt"
OUTPUTFILE_PRE_NEXT_5="target_domain_pre_next_5.txt"
OUTPUTFILE_PRE_NEXT_6="target_domain_pre_next_6.txt"
OUTPUTFILE="target_domain.txt"
INTERFACE_NAME=""
BRACE_LEFT="{"
BRACE_RIGHT="}"
BLANK=" "
TEMP_STR=
TEMP_STR2=
TEMP_STR3=
TEMP_STR4=
TEMP_STR5=
TEMP_STR6=
TEMP_STR6_1=
TEMP_STR7=
TEMP_STR7_2=
TEMP_STR7_3=
TEMP_STR7_4=
TEMP_STR7_5=
_TEMP_STR7_6=
TEMP_STR8=
TEMP_STR9=

ECHO_LINES(){
  while read LINE
	do
		echo $LINE | grep "::"
		#################for target domain################
		TEMP_STR=`echo $LINE | grep "allow" | awk '{ print $3 }'| awk -F":" '{ print $1 }'`
		TEMP_STR2=`echo $LINE | grep "allow" | awk '{ print $4 }'| awk -F":" '{ print $1 }'`
		#################for object class################
		TEMP_STR5=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk '{ print $1 }'`
		##########for permissions in { a b c }################
		TEMP_STR7=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk '{ print $2 }'`
		TEMP_STR7_2=`echo $TEMP_STR7 |grep "{"`
		TEMP_STR7_3=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk -F"{" '{ print $2 }'`
		TEMP_STR7_4=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk -F"{" '{ print $3 }'`
		TEMP_STR7_5=`echo $LINE | grep "allow" | awk -F":" '{ print $2 }' | awk -F"{" '{ print $4 }'`
		TEMP_STR7_6="$TEMP_STR7_3""$TEMP_STR7_4""$TEMP_STR7_5"
		##fixed in segatex-7.950 ########for target domain {x y z ...}################
		TEMP_STR9=`echo $LINE | grep "allow" | awk -F":{" '{ print $2 }' | awk -F"}" '{ print $1 }'`
		TEMP_STR10=`echo $LINE | grep "allow" | awk -F":{" '{ print $2 }' | awk -F"}" '{ print $2 }'`
		##end fixed in segatex-7.950 ########for target domain {x y z ...}################
		########### matches target domain { a_t b_t } and { a_t b_t } c_t } ##################### 
		if [ "$TEMP_STR" = "$BRACE_LEFT" ]; then
			TEMP_STR6=`echo $LINE | awk -F":" '{ print $1 }' | awk -F"{" '{ print $2 }' | awk -F"}" '{ print $1 }'`
			TEMP_STR6_1=`echo $LINE | awk -F":" '{ print $1 }' | awk -F"{" '{ print $2 }' | awk -F"}" '{ print $2 }'`
			echo "$TEMP_STR6""$TEMP_STR6_1""&""$TEMP_STR5""&""$TEMP_STR7""$TEMP_STR7_6"
		else
			##fixed in segatex-7.950 ########for target domain {x y z ...}################
                        if [ "$TEMP_STR" != "" ];then
                		echo "$TEMP_STR""&""$TEMP_STR9""&""$TEMP_STR10"
                        else
			##end fixed in segatex-7.950 ########for target domain {x y z ...}################
				echo "$TEMP_STR""&""$TEMP_STR5""&""$TEMP_STR7""$TEMP_STR7_6"
                        fi
		fi
		########### matches permissions { { a b c } } or { { a b c } d }##################### 
		if [ "$TEMP_STR" != "$BRACE_LEFT" ]; then
			if [ "$TEMP_STR7_2" != "" ]; then
				echo "$TEMP_STR""&""$TEMP_STR5""&""$TEMP_STR7_6"
				if [ "$TEMP_STR7" = "$BRACE_LEFT" ]; then
					TEMP_STR8=`echo $LINE | awk -F":" '{ print $2 }' | awk '{ print $2 }'`
					TEMP_STR9=`echo $LINE | awk -F":" '{ print $2 }' | awk '{ print $3 }'`
				else
					echo "$TEMP_STR""&""$TEMP_STR5""&""$TEMP_STR7_6"
				fi
			fi
		fi

	done < $INPUTFILE >> $OUTPUTFILE_PRE
}
if [ -r $OUTPUTFILE_PRE ]; then
	rm $OUTPUTFILE_PRE
fi
if [ -r $OUTPUTFILE_PRE_NEXT ]; then
	rm $OUTPUTFILE_PRE_NEXT
fi
if [ -r $OUTPUTFILE_PRE_NEXT_2 ]; then
	rm $OUTPUTFILE_PRE_NEXT_2
fi
if [ -r $OUTPUTFILE_PRE_NEXT_3 ]; then
	rm $OUTPUTFILE_PRE_NEXT_3
fi
if [ -r $OUTPUTFILE_PRE_NEXT_4 ]; then
	rm $OUTPUTFILE_PRE_NEXT_4
fi
if [ -r $OUTPUTFILE_PRE_NEXT_5 ]; then
	rm $OUTPUTFILE_PRE_NEXT_5
fi
if [ -r $OUTPUTFILE_PRE_NEXT_6 ]; then
	rm $OUTPUTFILE_PRE_NEXT_6
fi
if [ -r $OUTPUTFILE ]; then
	rm $OUTPUTFILE
fi
ECHO_LINES
sed 's/$(.*)?_t//g' $OUTPUTFILE_PRE > $OUTPUTFILE_PRE_NEXT
#sed 's/$[12]//g' $OUTPUTFILE_PRE_NEXT > $OUTPUTFILE_PRE_NEXT_2
sed 's/[{};]//g' $OUTPUTFILE_PRE_NEXT > $OUTPUTFILE_PRE_NEXT_2
sed 's/  / /g' $OUTPUTFILE_PRE_NEXT_2 > $OUTPUTFILE_PRE_NEXT_3
#sed '/^[$&]/d' $OUTPUTFILE_PRE_NEXT_3 > $OUTPUTFILE_PRE_NEXT_4
uniq $OUTPUTFILE_PRE_NEXT_3 > $OUTPUTFILE
rm $OUTPUTFILE_PRE
rm $OUTPUTFILE_PRE_NEXT
rm $OUTPUTFILE_PRE_NEXT_2
rm $OUTPUTFILE_PRE_NEXT_3
echo $OUTPUTFILE "was made !"

exit 0
